@@ -14,4 +14,4 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-glade_path = '/usr/local/lib/keysafe/gui'
+glade_path = '/home/magnus/opt/keysafe/lib/keysafe/gui'
